==> ace_5.4.7.orig.tar.gz: ACE_wrappers/examples/QOS/Change_Sender_TSpec/Sender_QoS_Event_Handler.h <==
/* -*- C++ -*- */
// Sender_QoS_Event_Handler.h,v 1.1 2001/04/10 05:27:55 yamuna Exp

// ============================================================================
//
// = LIBRARY
//    ACE_wrappers/examples/QOS
//
// = FILENAME
//    Sender_QoS_Event_Handler.h
//
// = AUTHOR
//    Vishal Kachroo <vishal@cs.wustl.edu>
//
// ============================================================================

#ifndef SENDER_QOS_EVENT_HANDLER_H
#define SENDER_QOS_EVENT_HANDLER_H

#include "ace/Event_Handler.h"
#include "ace/Reactor.h"
#include "ace/INET_Addr.h"
#include "ace/QoS/SOCK_Dgram_Mcast_QoS.h"
#include "ace/QoS/QoS_Session.h"

//#define MY_DEFPORT 5001
//#define DEFAULT_MULTICASTGROUP "234.5.6.7"

ACE_RCSID(Sender_QoS_Event_Handler, Sender_QoS_Event_Handler, "Sender_QoS_Event_Handler.h,v 1.1 2001/04/10 05:27:55 yamuna Exp")

class Sender_QoS_Event_Handler : public ACE_Event_Handler
{
public:
  // = Initialization and Termination methods.
  Sender_QoS_Event_Handler (void);
  // Constructor.

  Sender_QoS_Event_Handler::Sender_QoS_Event_Handler (const ACE_SOCK_Dgram_Mcast_QoS 
                                                      &dgram_mcast_qos,
                                                      ACE_QoS_Session *qos_session
                                                      );
  // Constructor.
  
  ~Sender_QoS_Event_Handler (void);
  // Destructor. 

  virtual ACE_HANDLE get_handle (void) const;
  // Override this to return the handle of the Dgram_Mcast
  // that we are using.

  virtual int handle_qos (ACE_HANDLE fd);
  // Handles a QoS event. Right now, just 
  // prints a message.

private:

  ACE_SOCK_Dgram_Mcast_QoS dgram_mcast_qos_;
  ACE_QoS_Session *qos_session_;
};

#endif  /* SENDER_QOS_EVENT_HANDLER_H */

==> ace_5.6.3.orig.tar.gz: ACE_wrappers/examples/QOS/Change_Sender_TSpec/Sender_QoS_Event_Handler.h <==
/* -*- C++ -*- */
// $Id: Sender_QoS_Event_Handler.h 80504 2008-01-26 06:47:13Z johnnyw $

// ============================================================================
//
// = LIBRARY
//    ACE_wrappers/examples/QOS
//
// = FILENAME
//    Sender_QoS_Event_Handler.h
//
// = AUTHOR
//    Vishal Kachroo <vishal@cs.wustl.edu>
//
// ============================================================================

#ifndef SENDER_QOS_EVENT_HANDLER_H
#define SENDER_QOS_EVENT_HANDLER_H

#include "ace/Event_Handler.h"
#include "ace/Reactor.h"
#include "ace/INET_Addr.h"
#include "ace/QoS/SOCK_Dgram_Mcast_QoS.h"
#include "ace/QoS/QoS_Session.h"

//#define MY_DEFPORT 5001
//#define DEFAULT_MULTICASTGROUP "234.5.6.7"

ACE_RCSID(Sender_QoS_Event_Handler, Sender_QoS_Event_Handler, "$Id: Sender_QoS_Event_Handler.h 80504 2008-01-26 06:47:13Z johnnyw $")

class Sender_QoS_Event_Handler : public ACE_Event_Handler
{
public:
  // = Initialization and Termination methods.
  Sender_QoS_Event_Handler (void);
  // Constructor.

  Sender_QoS_Event_Handler (const ACE_SOCK_Dgram_Mcast_QoS &dgram_mcast_qos,
                            ACE_QoS_Session *qos_session);
  // Constructor.

  ~Sender_QoS_Event_Handler (void);
  // Destructor.

  virtual ACE_HANDLE get_handle (void) const;
  // Override this to return the handle of the Dgram_Mcast
  // that we are using.

  virtual int handle_qos (ACE_HANDLE fd);
  // Handles a QoS event. Right now, just
  // prints a message.

private:

  ACE_SOCK_Dgram_Mcast_QoS dgram_mcast_qos_;
  ACE_QoS_Session *qos_session_;
};

#endif  /* SENDER_QOS_EVENT_HANDLER_H */
